
/******************************************************************************
    Filename: cc112x_dsss_mode_and_t_mode_reg_configh
    
    Description: Template for CC112x register export from SmartRF Studio 
                 
*******************************************************************************/

/******************************************************************************
 * INCLUDES
 */
#include "hal_spi_rf_trxeb.h"
#include "cc112x_spi.h"
  
/******************************************************************************
 * VARIABLES
 */

#define MAX_FIXED_LENGTH          256
#define FIXED_PACKET_LENGTH       0x00
#define INFINITE_PACKET_LENGTH    0x40
   
#define RX_FIFO_THRESHOLD         100 //(100+1 Bytes RX FIFO Threshold)
#define BYTES_IN_RX_FIFO          101     // # of bytes one can read from the RX_FIFO when a rising edge occur
                                            // on IOCFGx = 0x00 and FIFO_THR = 100
#define INFINITE                  0
#define FIXED                     1
#define MAX_FIXED_LENGTH          256
 
#define RX_STATE_ERROR            3

static uint8 packetReceived = FALSE;    // Flag asserted on falling edge 
                                        // GPIO2 (PKT_SYNC_RXTX)
static uint8 rxBuffer[437];             // DSSS packets = 152 bytes, wM-Bus = 291x 1.5 (3-of-6) = 437 Bytes
static uint8 RXbytes[291];                     // T-mode with 3-of-6 decoded bytes



static uint8 thresholdReached = FALSE;  // Flag asserted on rising edge 
                                        // of GPIO0 (RXFIFO_THR)
static uint16 dataOut[142];             // Array to hold the incoming data for 1562 chips /11-bits = 142 groups
static uint8 crcOK;                     // Flag asserted if the CRC is OK
static uint8 original[20] = {0};        // Buffer containing the decoded DSSS 
                                        // packet (15.5 bytes)
extern volatile uint8 dsssMode;          // Flag asserted if the sync word is a 
                                        // DSSS sync word (SYNC_LOW0_HIGH1 = 0)
extern volatile uint8 tMode;             // Flag asserted if the sync word is a 
                                        // T-Mode sync word (SYNC_LOW0_HIGH1 = 1)

extern volatile uint8 cMode;             // Flag asserted after the 1st Byte in T-mode is a C-Mode sync word (SYNC = 0x54)

static uint8 frmFormatB = FALSE; 

// Rf settings for CC1125
static const registerSetting_t preferredSettings[] = {
  {CC112X_FIFO_CFG,         0x64}, //there are at least 16 Bytes in each wM-Bus packet (regardles if T- or C-mode)

  {CC112X_IOCFG3,           0x06}, // PKT_SYNC_RXTX
  {CC112X_IOCFG2,           0x06}, // PKT_SYNC_RXTX
  {CC112X_IOCFG0,           0x00}, // FIFO Threshold reached
  
  //  Dual SYNC
  {CC112X_SYNC3,            0x54}, //T-mode
  {CC112X_SYNC2,            0x3D}, //T-mode
  
  {CC112X_SYNC1,            0x52}, //DSSS 16-bits
  {CC112X_SYNC0,            0x47}, //DSSS 16-bits
  
  
  {CC112X_SYNC_CFG1,        0x08},
  {CC112X_SYNC_CFG0,        0x1F},
//  {CC112X_DEVIATION_M,      0xd8}, //72kHz
  
  {CC112X_DEVIATION_M,      0xAA}, //65KhZ
  {CC112X_MODCFG_DEV_E,     0x0E},
  {CC112X_DCFILT_CFG,       0x0C},
  {CC112X_PREAMBLE_CFG1,    0x19},
  {CC112X_PREAMBLE_CFG0,    0x37},
  {CC112X_FREQ_IF_CFG,      0x00},
  {CC112X_IQIC,             0x00},
  {CC112X_CHAN_BW,          0x01},
  {CC112X_MDMCFG1,          0x46},
  {CC112X_MDMCFG0,          0x05},
  {CC112X_DRATE2,           0xA4},
  {CC112X_DRATE1,           0x7A},
  {CC112X_DRATE0,           0xE1},
  {CC112X_AGC_REF,          0x3C},
  {CC112X_AGC_CS_THR,       0xF9},
  {CC112X_AGC_GAIN_ADJUST,  0x00},
  {CC112X_AGC_CFG3,         0x03},
  {CC112X_AGC_CFG2,         0x20},
  {CC112X_AGC_CFG1,         0xA0},
  {CC112X_AGC_CFG0,         0xC0},
  {CC112X_SETTLING_CFG,     0x03},
  {CC112X_PKT_CFG2,         0x04},
  {CC112X_PKT_CFG1,         0x00}, //0x04
  {CC112X_PKT_CFG0,         0x00}, //0x00 is FIXED Length; 0x40 = INFINITE
  
  {CC112X_PKT_LEN,          0xFF}, //L=196 for DSSS; L=256 max for wM-Bus and DSSS
  {CC112X_PA_CFG0,          0x78},
  {CC112X_IF_MIX_CFG,       0x00},
  {CC112X_FREQOFF_CFG,      0x34},
  {CC112X_TOC_CFG,          0x0B},
  {CC112X_FREQ2,            0x56},
  {CC112X_FREQ1,            0xE5},
  {CC112X_FREQ0,            0x1E},
  {CC112X_IF_ADC0,          0x05},
  {CC112X_FS_DIG1,          0x00},
  {CC112X_FS_DIG0,          0x5F},
  {CC112X_FS_CAL0,          0x0E},
  {CC112X_FS_DIVTWO,        0x03},
  {CC112X_FS_DSM0,          0x33},
  {CC112X_FS_DVC0,          0x17},
  {CC112X_FS_PFD,           0x50},
  {CC112X_FS_PRE,           0x6E},
  {CC112X_FS_REG_DIV_CML,   0x14},
  {CC112X_FS_SPARE,         0xAC},
  {CC112X_XOSC5,            0x0E},
  {CC112X_XOSC3,            0xC7},
  {CC112X_XOSC1,            0x07},
  {CC112X_RFEND_CFG0,       0x08},
  {CC112X_LNA,       0x03},             //enable better sensitivity
};


/******************************************************************************
  Copyright 2011 Texas Instruments Incorporated. All rights reserved.

  IMPORTANT: Your use of this Software is limited to those specific rights
  granted under the terms of a software license agreement between the user
  who downloaded the software, his/her employer (which must be your employer)
  and Texas Instruments Incorporated (the "License").  You may not use this
  Software unless you agree to abide by the terms of the License. The License
  limits your use, and you acknowledge, that the Software may not be modified,
  copied or distributed unless embedded on a Texas Instruments microcontroller
  or used solely and exclusively in conjunction with a Texas Instruments radio
  frequency transceiver, which is integrated into your product.  Other than for
  the foregoing purpose, you may not use, reproduce, copy, prepare derivative
  works of, modify, distribute, perform, display or sell this Software and/or
  its documentation for any purpose.

  YOU FURTHER ACKNOWLEDGE AND AGREE THAT THE SOFTWARE AND DOCUMENTATION ARE
  PROVIDED AS IS WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESS OR IMPLIED,
  INCLUDING WITHOUT LIMITATION, ANY WARRANTY OF MERCHANTABILITY, TITLE,
  NON-INFRINGEMENT AND FITNESS FOR A PARTICULAR PURPOSE. IN NO EVENT SHALL
  TEXAS INSTRUMENTS OR ITS LICENSORS BE LIABLE OR OBLIGATED UNDER CONTRACT,
  NEGLIGENCE, STRICT LIABILITY, CONTRIBUTION, BREACH OF WARRANTY, OR OTHER
  LEGAL EQUITABLE THEORY ANY DIRECT OR INDIRECT DAMAGES OR EXPENSES
  INCLUDING BUT NOT LIMITED TO ANY INCIDENTAL, SPECIAL, INDIRECT, PUNITIVE
  OR CONSEQUENTIAL DAMAGES, LOST PROFITS OR LOST DATA, COST OF PROCUREMENT
  OF SUBSTITUTE GOODS, TECHNOLOGY, SERVICES, OR ANY CLAIMS BY THIRD PARTIES
  (INCLUDING BUT NOT LIMITED TO ANY DEFENSE THEREOF), OR OTHER SIMILAR COSTS.

  Should you have any questions regarding your right to use this Software,
  contact Texas Instruments Incorporated at www.TI.com.
*******************************************************************************/
