/**************************************************************************//**
    @file       hal_flash_trxeb.h

    @brief      SPI flash header file.

******************************************************************************/

#ifndef HAL_FLASH_ST25PE_H
#define HAL_FLASH_ST25PE_H

/******************************************************************************
* INCLUDES
*/
#include "hal_types.h"


/******************************************************************************
* MACROS
*/
#define FLASH_ADDR_TO_PAGE(addr)        ((uint16)(addr >> 8))
#define FLASH_PAGE_TO_ADDR(page)        ((((uint32)page) << 8))


/******************************************************************************
* CONSTANTS
*/
// Instructions
#define FLASH_INSTRUCTION_WREN          0x06
#define FLASH_INSTRUCTION_WRDI          0x04
#define FLASH_INSTRUCTION_RDID          0x9F
#define FLASH_INSTRUCTION_RDSR          0x05
#define FLASH_INSTRUCTION_READ          0x03
#define FLASH_INSTRUCTION_FAST_READ     0x0B
#define FLASH_INSTRUCTION_PW            0x0A
#define FLASH_INSTRUCTION_PP            0x02
#define FLASH_INSTRUCTION_PE            0xDB
#define FLASH_INSTRUCTION_SE            0xD8
#define FLASH_INSTRUCTION_DP            0xB9
#define FLASH_INSTRUCTION_RDP           0xAB

// Bitmasks of the status register
#define FLASH_STATUS_SRWD_BM            0x80
#define FLASH_STATUS_BP_BM              0x0C
#define FLASH_STATUS_WEL_BM             0x02
#define FLASH_STATUS_WIP_BM             0x01

// Power drivestrength
#define FLASH_PORT_PWR_DS               P7DS
// Other SPI flash pin configurations are defined in hal_board.h


/******************************************************************************
* PUBLIC FUNCTIONS
*/
void   halFlashInit(void);
void   halFlashUninit(void);
uint8  halFlashGetStatus(void);
uint32 halFlashGetId(void);
uint32 halFlashRead(uint32 address, uint8* data, uint32 bytes);
uint32 halFlashPageWrite(uint16 page, uint8* data, uint16 bytes);


/*****************************************************************************/
#endif


/******************************************************************************
  Copyright 2011 Texas Instruments Incorporated. All rights reserved.

  IMPORTANT: Your use of this Software is limited to those specific rights
  granted under the terms of a software license agreement between the user
  who downloaded the software, his/her employer (which must be your employer)
  and Texas Instruments Incorporated (the "License").  You may not use this
  Software unless you agree to abide by the terms of the License. The License
  limits your use, and you acknowledge, that the Software may not be modified,
  copied or distributed unless embedded on a Texas Instruments microcontroller
  or used solely and exclusively in conjunction with a Texas Instruments radio
  frequency transceiver, which is integrated into your product.  Other than for
  the foregoing purpose, you may not use, reproduce, copy, prepare derivative
  works of, modify, distribute, perform, display or sell this Software and/or
  its documentation for any purpose.

  YOU FURTHER ACKNOWLEDGE AND AGREE THAT THE SOFTWARE AND DOCUMENTATION ARE
  PROVIDED AS IS WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESS OR IMPLIED,
  INCLUDING WITHOUT LIMITATION, ANY WARRANTY OF MERCHANTABILITY, TITLE,
  NON-INFRINGEMENT AND FITNESS FOR A PARTICULAR PURPOSE. IN NO EVENT SHALL
  TEXAS INSTRUMENTS OR ITS LICENSORS BE LIABLE OR OBLIGATED UNDER CONTRACT,
  NEGLIGENCE, STRICT LIABILITY, CONTRIBUTION, BREACH OF WARRANTY, OR OTHER
  LEGAL EQUITABLE THEORY ANY DIRECT OR INDIRECT DAMAGES OR EXPENSES
  INCLUDING BUT NOT LIMITED TO ANY INCIDENTAL, SPECIAL, INDIRECT, PUNITIVE
  OR CONSEQUENTIAL DAMAGES, LOST PROFITS OR LOST DATA, COST OF PROCUREMENT
  OF SUBSTITUTE GOODS, TECHNOLOGY, SERVICES, OR ANY CLAIMS BY THIRD PARTIES
  (INCLUDING BUT NOT LIMITED TO ANY DEFENSE THEREOF), OR OTHER SIMILAR COSTS.

  Should you have any questions regarding your right to use this Software,
  contact Texas Instruments Incorporated at www.TI.com.
******************************************************************************/